@@ -1,3 +1,7 @@
+import sys
+import warnings
+from collections import Iterable
+
 import dash
 import dash_core_components as dcc
 import dash_cytoscape as cyto
@@ -5,6 +9,7 @@ import dash_html_components as html
 import networkx as nx
 from dash.dependencies import ClientsideFunction
 from dash.exceptions import PreventUpdate
+from time_series_metadata.scheme import MetaData
 
 from . import LayoutHelper
 from .LayoutHelper import create_edges_cytoscape, create_monitor_graph, \
@@ -430,6 +435,7 @@ class Dashboard_agt_net(Dashboard_Layout_Base):
                             sender_agent,
                             **custom_plot_parameters
                         )
+
                     if (
                             isinstance(traces, tuple)
                             or isinstance(traces, list)
@@ -443,6 +449,49 @@ class Dashboard_agt_net(Dashboard_Layout_Base):
                     y_title_offset = 0.1
                 else:
                     y_title_offset = -0.1
+
+                # Check if any metadata is present that can be used to generate axis
+                # labels or otherwise use default labels.
+                if (
+                    isinstance(memory_data[sender_agent], dict)
+                    and "metadata" in memory_data[sender_agent].keys()
+                ):
+                    # The metadata currently is always a list in the
+                    # beginning containing at least one element.
+                    desc = memory_data[sender_agent]["metadata"][0]
+
+                    # We now expect metadata to be of type
+                    # time-series-metadata.scheme.MetaData. We try to access the
+                    # object correspondingly and throw a meaningful error message in
+                    # case something goes wrong.
+                    try:
+                        t_name, t_unit = desc.time.values()
+                        v_name, v_unit = desc.get_quantity().values()
+                    except TypeError:
+                        raise TypeError(
+                            f"The Dashboard tried to access an agents metadata but an"
+                            f"error occurred. Metadata is " f"of type {type(desc)} "
+                            f"but is expected to be of type ""{type(MetaData)}. " 
+                            f"Its value is: \n\n{desc}"
+                        )
+
+                    # After successfully extracting the metadata itself, we concatenate
+                    # the important parts to get the labels.
+                    x_label = f"{t_name} [{t_unit}]"
+                    y_label = f"{v_name} [{v_unit}]"
+                else:
+                    # If no metadata is available we set reasonable defaults. Since
+                    # we could deal with any data in the time as well as in the
+                    # frequency domain, we keep it fairly generic.
+                    warnings.warn(
+                        f"The Dashboard shows a plot for monitor agent '"
+                        f"{monitor_agent}' without any axes labels specified. The "
+                        f"labels will be represented by generic place holders. Check "
+                        f"out tutorial 4 to find out how to specify custom labels."
+                    )
+                    x_label = "X"
+                    y_label = "Y"
+
                 monitor_graph = {
                     'data': data,
                     'layout': {
@@ -453,6 +502,8 @@ class Dashboard_agt_net(Dashboard_Layout_Base):
                             'xanchor': 'center',
                             'yanchor': 'bottom'
                         },
+                        'xaxis': {'title': {'text': x_label}},
+                        'yaxis': {'title': {'text': y_label}},
                         'uirevision': app.num_monitor,
                         'showlegend': True,
                         'legend': dict(xanchor='auto', yanchor='bottom', x=1, y=1, orientation="h"),
